UpdateSubcommand

Enum UpdateSubcommand 

pub enum UpdateSubcommand {
    Transactions(Box<UpdateTransactionsArgs>),
    Categories(UpdateCategoriesArgs),
    Autocats(UpdateAutoCatsArgs),
}
Subcommands for tiller update.

Variants



Transactions(Box<UpdateTransactionsArgs>)

Updates one or more transactions in the local SQLite database by their IDs. At least one transaction ID must be provided. When more than one ID is provided, all specified transactions are updated with the same field values.

Changes are made locally only. Use sync up to upload local changes to the Google Sheet.



Categories(UpdateCategoriesArgs)

Updates one or more categories in the local SQLite database by their names. At least one category name must be provided. When more than one name is provided, all specified categories are updated with the same field values.

Due to ON UPDATE CASCADE foreign key constraints, renaming a category automatically updates all references in transactions and autocat rules.

Changes are made locally only. Use sync up to upload local changes to the Google Sheet.



Autocats(UpdateAutoCatsArgs)

Updates one or more AutoCat rules in the local SQLite database by their IDs. At least one ID must be provided. When more than one ID is provided, all specified rules are updated with the same field values.

Changes are made locally only. Use sync up to upload local changes to the Google Sheet.