pub struct DeleteCategoriesArgs { /* private fields */ }Expand description
Args for the tiller delete categories command.
Deletes one or more categories from the local SQLite database by their names. At least one category name must be provided.
Due to ON DELETE RESTRICT foreign key constraints, a category cannot be deleted if any
transactions or AutoCat rules reference it. You must first update or delete those references
before deleting the category.
Changes are made locally only. Use sync up to upload local changes to the Google Sheet.
Warning: This operation cannot be undone locally. However, if you haven’t run sync up
yet, you can restore the categories by running sync down to re-download from the sheet.
Implementations