pub struct DeleteTransactionsArgs { /* private fields */ }Expand description
Args for the tiller delete transactions command.
Deletes one or more transactions from the local SQLite database by their IDs. At least one transaction ID must be provided.
Changes are made locally only. Use sync up to upload local changes to the Google Sheet.
Warning: This operation cannot be undone locally. However, if you haven’t run sync up
yet, you can restore the transactions by running sync down to re-download from the sheet.
Implementations