pub struct UpdateCategoriesArgs { /* private fields */ }Expand description
Args for the tiller update categories command.
Updates one or more categories in the local SQLite database by their names. At least one category name must be provided. When more than one name is provided, all specified categories are updated with the same field values.
The category name is the primary key. To rename a category, provide a single name and set
the --category update field to the new name.
Due to ON UPDATE CASCADE foreign key constraints, renaming a category automatically
updates all references in transactions and autocat rules.
Changes are made locally only. Use sync up to upload local changes to the Google Sheet.
Implementations
Sourceimpl UpdateCategoriesArgs
impl UpdateCategoriesArgs
pub fn new<S, I>(names: I, updates: CategoryUpdates) -> Result<Self>
pub fn names(&self) -> &[String]
pub fn updates(&self) -> &CategoryUpdates