pub struct UpdateTransactionsArgs { /* private fields */ }Expand description
Args for the tiller update transactions command.
Updates one or more transactions in the local SQLite database by their IDs. At least one transaction ID must be provided. When more than one ID is provided, all specified transactions are updated with the same field values.
Changes are made locally only. Use sync up to upload local changes to the Google Sheet.
Implementations
Sourceimpl UpdateTransactionsArgs
impl UpdateTransactionsArgs
pub fn new<S, I>(ids: I, updates: TransactionUpdates) -> Result<Self>
pub fn ids(&self) -> &[String]
pub fn updates(&self) -> &TransactionUpdates