pub struct ColumnInfo {
pub name: String,
pub data_type: String,
pub nullable: bool,
pub primary_key: bool,
pub description: Option<String>,
}Expand description
Information about a table column.
Fields
name: StringColumn name.
data_type: StringSQLite data type.
nullable: boolWhether the column allows NULL values.
primary_key: boolWhether the column is part of the primary key.
description: Option<String>Description of the column from model doc comments (if available).