pub struct Amount { /* private fields */ }Expand description
Represents a dollar amount.
This type wraps Decimal and provides custom serialization/deserialization
to handle amounts that may be formatted with or without dollar signs or commas.
Formatting is considered significant for the purposes of equality, so for numeric comparisons,
you should access the Decimal value and use that.
Examples
Parsing with dollar sign:
let amount = Amount::from_str("-$50.00").unwrap();
assert_eq!(amount.to_string(), "-$50.00");Parsing without dollar sign:
let amount = Amount::from_str("-50.00").unwrap();
assert_ne!(amount.to_string(), "-$50.00");
assert_eq!(amount.to_string(), "-50.00");Value equivalency, but not absolute equivalency
let a = Amount::from_str("-5000.00").unwrap();
let b = Amount::from_str("-$5,000.00").unwrap();
assert_ne!(a, b);
assert_ne!(a.to_string(), b.to_string());
assert_eq!(a.value(), b.value());Implementations
Sourceimpl Amount
impl Amount
Sourcepub const fn new(value: Decimal) -> Self
pub const fn new(value: Decimal) -> Self
Creates a new Amount from a Decimal value with default String formatting.
Sourcepub const fn new_with_format(value: Decimal, format: AmountFormat) -> Self
pub const fn new_with_format(value: Decimal, format: AmountFormat) -> Self
Creates a new Amount from a Decimal value with default specified formatting.
Sourcepub fn is_positive(&self) -> bool
pub fn is_positive(&self) -> bool
Returns true if the amount is positive.
Sourcepub fn is_negative(&self) -> bool
pub fn is_negative(&self) -> bool
Returns true if the amount is negative.