pub struct Transaction { /* private fields */ }Expand description
Represents a single row from the Transactions sheet. See tiller documentation for more information about the semantic meanings of transaction columns: https://help.tiller.com/en/articles/432681-transactions-sheet-columns
Implementations
Sourceimpl Transaction
impl Transaction
Sourcepub fn merge_updates(&mut self, update: TransactionUpdates)
pub fn merge_updates(&mut self, update: TransactionUpdates)
Set any of the fields on self that are set in update.