pub struct TillerError { /* private fields */ }Expand description
This library’s public error type
Implementations
Sourceimpl TillerError
impl TillerError
Sourcepub fn error_type(&self) -> ErrorType
pub fn error_type(&self) -> ErrorType
The ErrorType of the TillerError
Sourcepub fn is_protocol_error(&self) -> bool
pub fn is_protocol_error(&self) -> bool
Returns true if this should be categorized as an MCP protocol error.
Protocol errors should be converted to ErrorData in MCP responses.
Sourcepub fn is_tool_error(&self) -> bool
pub fn is_tool_error(&self) -> bool
Returns true if this should be categorized as a tool error for MCP.
Tool errors should be converted to CallToolResult::error() in MCP responses.