pub enum DeleteSubcommand {
Transactions(DeleteTransactionsArgs),
Categories(DeleteCategoriesArgs),
Autocats(DeleteAutoCatsArgs),
}Expand description
Subcommands for tiller delete.
Variants
Transactions(DeleteTransactionsArgs)
Deletes one or more transactions from the local SQLite database by their IDs. At least one transaction ID must be provided.
Changes are made locally only. Use sync up to upload local changes to the Google Sheet.
Warning: This operation cannot be undone locally. However, if you haven’t run sync up
yet, you can restore the transactions by running sync down to re-download from the sheet.
Categories(DeleteCategoriesArgs)
Deletes one or more categories from the local SQLite database by their names.
Due to ON DELETE RESTRICT foreign key constraints, a category cannot be deleted if any
transactions or AutoCat rules reference it. You must first update or delete those
references before deleting the category.
Changes are made locally only. Use sync up to upload local changes to the Google Sheet.
Warning: This operation cannot be undone locally. However, if you haven’t run sync up
yet, you can restore the categories by running sync down to re-download from the sheet.
Autocats(DeleteAutoCatsArgs)
Deletes one or more AutoCat rules from the local SQLite database by their IDs.
AutoCat rules have synthetic auto-increment IDs assigned when first synced down or inserted locally.
Changes are made locally only. Use sync up to upload local changes to the Google Sheet.
Warning: This operation cannot be undone locally. However, if you haven’t run sync up
yet, you can restore the rules by running sync down to re-download from the sheet.