pub struct DeleteAutoCatsArgs { /* private fields */ }Expand description
Args for the tiller delete autocats command.
Deletes one or more AutoCat rules from the local SQLite database by their IDs. At least one ID must be provided.
AutoCat rules have synthetic auto-increment IDs assigned when first synced down or inserted locally.
Changes are made locally only. Use sync up to upload local changes to the Google Sheet.
Warning: This operation cannot be undone locally. However, if you haven’t run sync up
yet, you can restore the rules by running sync down to re-download from the sheet.
Implementations