pub struct UpdateAutoCatsArgs { /* private fields */ }Expand description
Args for the tiller update autocats command.
Updates one or more AutoCat rules in the local SQLite database by their IDs. At least one ID must be provided. When more than one ID is provided, all specified rules are updated with the same field values.
AutoCat rules have a synthetic auto-increment primary key that is assigned when first synced down or inserted locally.
Changes are made locally only. Use sync up to upload local changes to the Google Sheet.
Implementations
Sourceimpl UpdateAutoCatsArgs
impl UpdateAutoCatsArgs
pub fn new<S, I>(ids: I, updates: AutoCatUpdates) -> Result<Self>
pub fn ids(&self) -> &[String]
pub fn updates(&self) -> &AutoCatUpdates